@@ -63,24 +63,14 @@ void InformationBox::setOpacity(qreal opacity) {
     }
 }
 
-void InformationBox::setFocus(bool focus) {
-    Q_D(const InformationBox);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 void InformationBox::changeEvent(QEvent *event) {
     switch (event->type()) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
