@@ -27,7 +27,6 @@ class ItemPrivate
 public:
     ItemPrivate(QWidget *parent) :
         q_ptr(parent),
-        keys(0),
         anc(0),
         left(AnchorLine(parent, AnchorLine::Left)),
         right(AnchorLine(parent, AnchorLine::Right)),
@@ -48,8 +47,6 @@ public:
 
     static void actions_append(QDeclarativeListProperty<QObject> *list, QObject *obj);
 
-    Keys* attachedKeys();
-
     Anchors* anchors();
 
     virtual QDeclarativeListProperty<QObject> data();
@@ -68,8 +65,6 @@ public:
 
     QWidget *q_ptr;
 
-    Keys* keys;
-
     Anchors *anc;
 
     AnchorLine left;
