@@ -70,19 +70,6 @@ void Text::setOpacity(qreal opacity) {
     }
 }
 
-void Text::setFocus(bool focus) {
-    Q_D(const Text);
-
-    if ((d->complete) && (focus != this->hasFocus())) {
-        if (focus) {
-            this->setFocus(Qt::OtherFocusReason);
-        }
-        else {
-            this->clearFocus();
-        }
-    }
-}
-
 QString Text::text() const {
     Q_D(const Text);
 
@@ -154,6 +141,9 @@ void Text::changeEvent(QEvent *event) {
     case QEvent::ParentChange:
         emit parentChanged();
         break;
+    case QEvent::EnabledChange:
+        emit enabledChanged();
+        break;
     default:
         break;
     }
