@@ -41,7 +41,7 @@ class Window : public QMainWindow, public QDeclarativeParserStatus
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
     Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
     Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged)
-    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
     Q_PROPERTY(AnchorLine top READ top CONSTANT FINAL)
@@ -52,6 +52,7 @@ class Window : public QMainWindow, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(Window::d_func(), QDeclarativeListProperty<QWidget> children READ children)
     Q_PRIVATE_PROPERTY(Window::d_func(), QDeclarativeListProperty<QObject> tools READ tools)
     Q_PRIVATE_PROPERTY(Window::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
+    Q_PRIVATE_PROPERTY(Window::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -76,8 +77,6 @@ public:
     qreal opacity() const;
     void setOpacity(qreal opacity);
 
-    void setFocus(bool focus);
-
     AnchorLine left() const;
     AnchorLine right() const;
     AnchorLine top() const;
@@ -96,6 +95,7 @@ signals:
     void heightChanged();
     void opacityChanged();
     void visibleChanged();
+    void enabledChanged();
     void focusChanged();
     void orientationLockChanged();
     void inPortraitChanged();
@@ -104,16 +104,16 @@ signals:
 protected:
     Window(WindowPrivate &dd, QWidget *parent = 0);
 
-    void showEvent(QShowEvent *event);
-    void hideEvent(QHideEvent *event);
-    void changeEvent(QEvent *event);
-    void moveEvent(QMoveEvent *event);
-    void resizeEvent(QResizeEvent *event);
-    void focusInEvent(QFocusEvent *event);
-    void focusOutEvent(QFocusEvent *event);
+    virtual void showEvent(QShowEvent *event);
+    virtual void hideEvent(QHideEvent *event);
+    virtual void changeEvent(QEvent *event);
+    virtual void moveEvent(QMoveEvent *event);
+    virtual void resizeEvent(QResizeEvent *event);
+    virtual void focusInEvent(QFocusEvent *event);
+    virtual void focusOutEvent(QFocusEvent *event);
 
-    void classBegin();
-    void componentComplete();
+    virtual void classBegin();
+    virtual void componentComplete();
 
     QScopedPointer<WindowPrivate> d_ptr;
 
